@@ -5,7 +5,7 @@ from sybil import Sybil
 from doctest import ELLIPSIS, REPORT_NDIFF, NORMALIZE_WHITESPACE
 from contextlib import ExitStack
 from sybil.parsers.doctest import DocTestParser
-from sybil.parsers.codeblock import CodeBlockParser
+from sybil.parsers.codeblock import PythonCodeBlockParser
 
 # For the message catalog used in the doctests.
 from test.data import messages
@@ -38,8 +38,9 @@ namespace = DoctestNamespace()
 pytest_collect_file = Sybil(
     parsers=[
         DocTestParser(optionflags=DOCTEST_FLAGS),
-        CodeBlockParser(),
+        PythonCodeBlockParser(),
         ],
     pattern='*.rst',
     setup=namespace.setup,
+    teardown=namespace.teardown,
     ).pytest()
